@@ -18,13 +18,13 @@ from designate.backend import impl_pdns4
 from designate import context
 from designate import exceptions
 from designate import objects
-from designate.tests import fixtures
+from designate.tests import base_fixtures
 
 
 class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
     def setUp(self):
-        super(PDNS4BackendTestCase, self).setUp()
-        self.stdlog = fixtures.StandardLogging()
+        super().setUp()
+        self.stdlog = base_fixtures.StandardLogging()
         self.useFixture(self.stdlog)
 
         self.context = mock.Mock()
@@ -33,7 +33,7 @@ class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
             context.DesignateContext, 'get_admin_context',
             return_value=self.admin_context).start()
 
-        self.base_address = 'http://localhost:8081/api/v1/servers'
+        self.base_address = 'http://203.0.113.1:8081/api/v1/servers'
         self.zone = objects.Zone(
             id='e2bed4dc-9d01-11e4-89d3-123b93f75cba',
             name='example.com.',
@@ -47,7 +47,7 @@ class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
                 {'host': '192.0.2.2', 'port': 35},
             ],
             'options': [
-                {'key': 'api_endpoint', 'value': 'http://localhost:8081'},
+                {'key': 'api_endpoint', 'value': 'http://203.0.113.1:8081'},
                 {'key': 'api_token', 'value': 'api_key'},
                 {'key': 'api_ca_cert', 'value': ''}
             ],
@@ -63,7 +63,7 @@ class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
             '%s/localhost/zones' % self.base_address,
         )
         req_mock.get(
-            '%s/localhost/zones/%s' % (self.base_address, self.zone.name),
+            f'{self.base_address}/localhost/zones/{self.zone.name}',
             status_code=404,
         )
 
@@ -72,9 +72,9 @@ class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
         self.assertEqual(
             req_mock.last_request.json(),
             {
-                'kind': u'slave',
+                'kind': 'slave',
                 'masters': ['192.0.2.1:53', '192.0.2.2:35'],
-                'name': u'example.com.',
+                'name': 'example.com.',
             }
         )
 
@@ -96,7 +96,7 @@ class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
             '%s/localhost/zones' % self.base_address,
         )
         req_mock.get(
-            '%s/localhost/zones/%s' % (self.base_address, self.zone.name),
+            f'{self.base_address}/localhost/zones/{self.zone.name}',
             status_code=404,
         )
 
@@ -105,9 +105,9 @@ class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
         self.assertEqual(
             req_mock.last_request.json(),
             {
-                'kind': u'slave',
+                'kind': 'slave',
                 'masters': ['[2001:db8::9abc]:53'],
-                'name': u'example.com.',
+                'name': 'example.com.',
             }
         )
 
@@ -121,7 +121,7 @@ class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
             '%s/localhost/zones' % self.base_address,
         )
         req_mock.get(
-            '%s/localhost/zones/%s' % (self.base_address, self.zone.name),
+            f'{self.base_address}/localhost/zones/{self.zone.name}',
             status_code=200,
         )
         req_mock.delete(
@@ -133,9 +133,9 @@ class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
         self.assertEqual(
             req_mock.last_request.json(),
             {
-                'kind': u'slave',
+                'kind': 'slave',
                 'masters': ['192.0.2.1:53', '192.0.2.2:35'],
-                'name': u'example.com.',
+                'name': 'example.com.',
             }
         )
 
@@ -150,7 +150,7 @@ class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
             status_code=500,
         )
         req_mock.get(
-            '%s/localhost/zones/%s' % (self.base_address, self.zone.name),
+            f'{self.base_address}/localhost/zones/{self.zone.name}',
             status_code=200,
         )
         req_mock.delete(
@@ -169,14 +169,14 @@ class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
             "Could not delete pre-existing zone "
             "<Zone id:'e2bed4dc-9d01-11e4-89d3-123b93f75cba' "
             "type:'None' name:'example.com.' pool_id:'None' serial:'None' "
-            "action:'None' status:'None'>",
+            "action:'None' status:'None' shard:'None'>",
             self.stdlog.logger.output
         )
 
         self.assertIn(
             "<Zone id:'e2bed4dc-9d01-11e4-89d3-123b93f75cba' type:'None' "
             "name:'example.com.' pool_id:'None' serial:'None' action:'None' "
-            "status:'None'> exists on the server. "
+            "status:'None' shard:'None'> exists on the server. "
             "Deleting zone before creation",
             self.stdlog.logger.output
         )
@@ -187,7 +187,7 @@ class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
             '%s/localhost/zones' % self.base_address,
         )
         req_mock.get(
-            '%s/localhost/zones/%s' % (self.base_address, self.zone.name),
+            f'{self.base_address}/localhost/zones/{self.zone.name}',
             status_code=404,
         )
 
@@ -204,9 +204,9 @@ class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
         self.assertEqual(
             req_mock.last_request.json(),
             {
-                'kind': u'slave',
+                'kind': 'slave',
                 'masters': ['192.0.2.1:53', '192.0.2.2:35'],
-                'name': u'example.com.',
+                'name': 'example.com.',
                 'slave_tsig_key_ids': ['tsig_key'],
             }
         )
@@ -222,7 +222,7 @@ class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
             status_code=500,
         )
         req_mock.get(
-            '%s/localhost/zones/%s' % (self.base_address, self.zone.name),
+            f'{self.base_address}/localhost/zones/{self.zone.name}',
             status_code=404,
         )
 
@@ -244,7 +244,7 @@ class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
             status_code=500,
         )
         req_mock.get(
-            '%s/localhost/zones/%s' % (self.base_address, self.zone.name),
+            f'{self.base_address}/localhost/zones/{self.zone.name}',
             [{'status_code': 404}, {'status_code': 200}],
         )
         req_mock.delete(
@@ -266,7 +266,8 @@ class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
         self.assertIn(
             "<Zone id:'e2bed4dc-9d01-11e4-89d3-123b93f75cba' type:'None' "
             "name:'example.com.' pool_id:'None' serial:'None' action:'None' "
-            "status:'None'> was created with an error. Deleting zone",
+            "status:'None' shard:'None'> was created with an error. "
+            "Deleting zone",
             self.stdlog.logger.output
         )
 
@@ -274,7 +275,7 @@ class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
             "Could not delete errored zone "
             "<Zone id:'e2bed4dc-9d01-11e4-89d3-123b93f75cba' type:'None' "
             "name:'example.com.' pool_id:'None' serial:'None' action:'None' "
-            "status:'None'>",
+            "status:'None' shard:'None'>",
             self.stdlog.logger.output
         )
 
@@ -284,7 +285,7 @@ class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
             '%s/localhost/zones/example.com.' % self.base_address,
         )
         req_mock.get(
-            '%s/localhost/zones/%s' % (self.base_address, self.zone.name),
+            f'{self.base_address}/localhost/zones/{self.zone.name}',
             status_code=200,
         )
 
@@ -302,7 +303,7 @@ class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
 
         # pdns returns 422 if asked about a zone that doesn't exist.
         req_mock.get(
-            '%s/localhost/zones/%s' % (self.base_address, self.zone.name),
+            f'{self.base_address}/localhost/zones/{self.zone.name}',
             status_code=422,
         )
 
@@ -319,7 +320,7 @@ class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
             status_code=500,
         )
         req_mock.get(
-            '%s/localhost/zones/%s' % (self.base_address, self.zone.name),
+            f'{self.base_address}/localhost/zones/{self.zone.name}',
             status_code=200,
         )
 
@@ -333,3 +334,31 @@ class PDNS4BackendTestCase(oslotest.base.BaseTestCase):
         self.assertEqual(
             req_mock.last_request.headers.get('X-API-Key'), 'api_key'
         )
+
+    @mock.patch('os.path.exists')
+    def test_verify_ssl(self, mock_path_exists):
+        mock_path_exists.return_value = True
+
+        self.backend.api_ca_cert = 'valid_cert'
+
+        self.assertEqual('valid_cert', self.backend._verify_ssl())
+
+    @mock.patch('os.path.exists')
+    def test_verify_ssl_does_not_exist(self, mock_path_exists):
+        mock_path_exists.return_value = False
+
+        self.backend.api_ca_cert = 'valid_cert'
+
+        self.assertFalse(self.backend._verify_ssl())
+
+    def test_verify_ssl_not_valid(self):
+        self.assertFalse(self.backend._verify_ssl())
+
+        self.backend.api_ca_cert = 'changeme'
+        self.assertFalse(self.backend._verify_ssl())
+
+        self.backend.api_ca_cert = ''
+        self.assertFalse(self.backend._verify_ssl())
+
+        self.backend.api_ca_cert = None
+        self.assertFalse(self.backend._verify_ssl())
